@@ -48,6 +48,8 @@ field to calibrate.
 import os
 import sys
 
+from termcolor import cprint
+
 usage_message = """
 USAGE:
 
@@ -71,13 +73,13 @@ import utils as ut
 ################################################################################
 # Read parameters
 
-print("""
+cprint("""
 ************************************************************************
 *                                                                      *
 *                   Starting the calibration pipeline                  *
 *                                                                      *
 ************************************************************************
-""")
+""", color = "cyan")
 
 cwd = os.getcwd()
 
@@ -91,8 +93,8 @@ except IndexError:
 
 pipeline_path = os.path.split(__file__)[0]
 
-print(conf_file)
-print("reading the configuration file")
+cprint(conf_file, color = "white", attrs=["dark"])
+cprint("******* reading the configuration file *******", color = "yellow")
 conf = ut.pipeline_conf(conf_file)
 
 ################################################################################
@@ -119,25 +121,29 @@ with open(log_file, "w") as log:
 
 print("\n\n")
 
-ut.printlog("*********** Reading configuratrion file **********", log_file)
+ut.printlog("*********** Reading configuratrion file **********", log_file, 
+            color = "yellow")
 
 for param in list(conf.keys()):
-    ut.printlog(f"{param}: {conf[param]}", log_file)
+    ut.printlog(f"{param}: {conf[param]}", log_file, 
+                color = "blue")
 
 print("\n\n")
 
 ################################################################################
 # Reading field list
 
-ut.printlog("*********** Reading field list **********", log_file)
+ut.printlog("*********** Reading field list **********", log_file,
+           color = "yellow")
 
 if '--onefield' in sys.argv:
     fields = [sys.argv[1]]
 else:
     fields = ut.load_field_list(field_list_file)
 
-ut.printlog(f"Running the pipeline for fields:", log_file)
-ut.printlog(f"{fields}", log_file)
+ut.printlog(f"Running the pipeline for fields:", log_file, color = "yellow")
+ut.printlog(f"{fields}", log_file, 
+            color = "yellow", attrs = ["bold"])
 
 ################################################################################
 # Running pipeline for each field
@@ -150,7 +156,7 @@ for field in fields:
     *                Working on field {field:37}*
     *                                                                      *
     ************************************************************************
-    """, log_file)
+    """, log_file, color = "cyan", attrs = ["bold"])
 
     #################
     # Make field path
@@ -158,19 +164,30 @@ for field in fields:
     logs_path = os.path.join(field_path, 'logs')
 
     field_images_path = os.path.join(field_path, 'Images')
+    
+    if "--skip_missing_images" in sys.argv:
+        source_images_path = os.path.join(conf["path_to_images"], field)
+        if not os.path.exists(source_images_path):
+            ut.printlog(f"{field} images not found. Skipping to next field\n\n",
+                        log_file, color = "white", attrs = ["dark"])
+            continue
 
     if not os.path.exists(field_path):
         ut.makedir(field_path)
-        ut.printlog(f"Created directory {field_path}.", log_file)
+        ut.printlog(f"Created directory {field_path}.", log_file,
+                    color = "green", attrs=["bold"])
 
         ut.makedir(logs_path)
-        ut.printlog(f"Created directory {logs_path}.", log_file)
+        ut.printlog(f"Created directory {logs_path}.", log_file,
+                    color = "green", attrs=["bold"])
 
         ut.makedir(field_images_path)
-        ut.printlog(f"Created directory {field_images_path}.", log_file)
+        ut.printlog(f"Created directory {field_images_path}.", log_file,
+                    color = "green", attrs=["bold"])
 
     else:
-        ut.printlog(f"Directory {field_path} already exists.", log_file)
+        ut.printlog(f"Directory {field_path} already exists.", log_file,
+                    color = "white", attrs=["bold", "dark"])
 
     print("")
 
@@ -180,7 +197,7 @@ for field in fields:
     if conf['run_path'] != conf['save_path']:
         field_save_path = os.path.join(conf['save_path'], field)
         cmd = f"rsync --update -haz --progress {field_save_path} {conf['run_path']}"
-        ut.printlog(cmd, log_file)
+        ut.printlog(cmd, log_file, color = "blue")
         os.system(cmd)
         print("")
 
@@ -196,7 +213,7 @@ for field in fields:
 
     # Make backup of config file
     cmd = f"cp {conf_file} {logs_path}"
-    ut.printlog(cmd, log_field_file)
+    ut.printlog(cmd, log_field_file, color = "green")
     os.system(cmd)
 
     # Run steps
@@ -255,15 +272,16 @@ for field in fields:
 
             if not os.path.exists(image_fz):
 
-                ut.printlog(f"Copying image {image_name}", log_field_file)
+                ut.printlog(f"Copying image {image_name}", log_field_file,
+                            color = "yellow")
 
                 cmd = f"cp {image_db_fz} {field_images_path}"
-                ut.printlog(cmd, log_field_file)
+                ut.printlog(cmd, log_field_file, color = "green")
                 os.system(cmd)
 
             else:
                 ut.printlog(f"Image {image_fz} already exists",
-                            log_field_file)
+                            log_field_file, color = "white", attrs = ["dark"])
             
 
             if conf['use_weight']:
@@ -273,12 +291,13 @@ for field in fields:
 
                 if not os.path.exists(weight_fz):
                     cmd = f"cp {weight_db_fz} {field_images_path}"
-                    ut.printlog(cmd, log_field_file)
+                    ut.printlog(cmd, log_field_file, color = "green")
                     os.system(cmd)
 
                 else:
                     ut.printlog(f"Image {weight_fz} already exists",
-                                log_field_file)
+                                log_field_file, 
+                                color = "white", attrs = ["dark"])
 
             #######################
             # Unpacking fits images
@@ -287,12 +306,14 @@ for field in fields:
 
             if not os.path.exists(image_fits):
 
-                ut.printlog(f"Unpacking image {image_fz}", log_field_file)
+                ut.printlog(f"Unpacking image {image_fz}", log_field_file,
+                            color = "yellow")
                 ut.fz2fits(image_fz)
 
             else:
                 ut.printlog(f"Image {image_fits} already exists",
-                            log_field_file)
+                            log_field_file, color = "white", attrs = ["dark"])
+                
                 
             if conf['use_weight']:
                 weight_fz = image_fz.replace(".fz", "weight.fz")
@@ -300,12 +321,13 @@ for field in fields:
 
                 if not os.path.exists(weight_fits):             
                     ut.printlog(f"Unpacking weight {weight_fz}",
-                                log_field_file)
+                                log_field_file, color = "yellow")
                     ut.fz2fits(weight_fz)
 
                 else:
                     ut.printlog(f"Image {weight_fits} already exists",
-                                log_field_file)
+                                log_field_file, 
+                                color = "white", attrs = ["dark"])
 
             print("")
 
@@ -321,7 +343,8 @@ for field in fields:
         if not os.path.exists(final_file):
             script = os.path.join(pipeline_path,'steps','photometry_single.py')
             cmd = f'python3 {script} {field} {conf_file}'
-            ut.printlog(cmd, log_field_file)
+            ut.printlog(cmd, log_field_file, 
+                        color = "blue", on_color = "on_white")
             os.system(cmd)
 
             print("\n\n")
@@ -334,7 +357,8 @@ for field in fields:
         if not os.path.exists(final_file):
             script = os.path.join(pipeline_path, 'steps', 'photometry_dual.py')
             cmd = f'python3 {script} {field} {conf_file}'
-            ut.printlog(cmd, log_field_file)
+            ut.printlog(cmd, log_field_file,
+                        color = "blue", on_color = "on_white")
             os.system(cmd)
 
             print("\n\n")
@@ -347,7 +371,8 @@ for field in fields:
         if not os.path.exists(final_file):
             script = os.path.join(pipeline_path, 'steps', 'photometry_psf.py')
             cmd = f'python3 {script} {field} {conf_file}'
-            ut.printlog(cmd, log_field_file)
+            ut.printlog(cmd, log_field_file,
+                        color = "blue", on_color = "on_white")
             os.system(cmd)
 
             print("\n\n")
@@ -356,7 +381,8 @@ for field in fields:
 
         script = os.path.join(pipeline_path, 'steps', 'correction_xy.py')
         cmd = f'python3 {script} {field} {conf_file}'
-        ut.printlog(cmd, log_field_file)
+        ut.printlog(cmd, log_field_file,
+                    color = "blue", on_color = "on_white")
         os.system(cmd)
 
         print("\n\n")
@@ -365,16 +391,18 @@ for field in fields:
 
         script = os.path.join(pipeline_path, 'steps', 'correction_aper.py')
         cmd = f'python3 {script} {field} {conf_file}'
-        ut.printlog(cmd, log_field_file)
+        ut.printlog(cmd, log_field_file,
+                    color = "blue", on_color = "on_white")
         os.system(cmd)
 
         print("\n\n")
 
     if 'photometry_id' in conf['run_steps']:
 
-        script = os.path.join(pipeline_path, 'steps', 'photometry_id.py')
+        script = os.path.join(pipeline_path, 'steps', 'photometry_ID.py')
         cmd = f'python3 {script} {field} {conf_file}'
-        ut.printlog(cmd, log_field_file)
+        ut.printlog(cmd, log_field_file,
+                    color = "blue", on_color = "on_white")
         os.system(cmd)
 
         print("\n\n")
@@ -383,7 +411,8 @@ for field in fields:
 
         script = os.path.join(pipeline_path, 'steps', 'photometry_master.py')
         cmd = f'python3 {script} {field} {conf_file}'
-        ut.printlog(cmd, log_field_file)
+        ut.printlog(cmd, log_field_file,
+                    color = "blue", on_color = "on_white")
         os.system(cmd)
 
         print("\n\n")
@@ -392,7 +421,8 @@ for field in fields:
 
         script = os.path.join(pipeline_path, 'steps', 'crossmatch.py')
         cmd = f'python3 {script} {field} {conf_file}'
-        ut.printlog(cmd, log_field_file)
+        ut.printlog(cmd, log_field_file,
+                    color = "blue", on_color = "on_white")
         os.system(cmd)
 
         print("\n\n")
@@ -401,7 +431,8 @@ for field in fields:
 
         script = os.path.join(pipeline_path, 'steps', 'calibration_external.py')
         cmd = f'python3 {script} {field} {conf_file}'
-        ut.printlog(cmd, log_field_file)
+        ut.printlog(cmd, log_field_file,
+                    color = "blue", on_color = "on_white")
         os.system(cmd)
 
         print("\n\n")
@@ -410,7 +441,8 @@ for field in fields:
 
         script = os.path.join(pipeline_path, 'steps', 'calibration_stloc.py')
         cmd = f'python3 {script} {field} {conf_file}'
-        ut.printlog(cmd, log_field_file)
+        ut.printlog(cmd, log_field_file,
+                    color = "blue", on_color = "on_white")
         os.system(cmd)
 
         print("\n\n")
@@ -419,7 +451,8 @@ for field in fields:
 
         script = os.path.join(pipeline_path, 'steps', 'calibration_internal.py')
         cmd = f'python3 {script} {field} {conf_file}'
-        ut.printlog(cmd, log_field_file)
+        ut.printlog(cmd, log_field_file,
+                    color = "blue", on_color = "on_white")
         os.system(cmd)
 
         print("\n\n")
@@ -428,7 +461,8 @@ for field in fields:
 
         script = os.path.join(pipeline_path, 'steps', 'calibration_gaiascale.py')
         cmd = f'python3 {script} {field} {conf_file}'
-        ut.printlog(cmd, log_field_file)
+        ut.printlog(cmd, log_field_file,
+                    color = "blue", on_color = "on_white")
         os.system(cmd)
 
         print("\n\n")
@@ -437,7 +471,8 @@ for field in fields:
 
         script = os.path.join(pipeline_path, 'steps', 'calibration_diagnostic.py')
         cmd = f'python3 {script} {field} {conf_file}'
-        ut.printlog(cmd, log_field_file)
+        ut.printlog(cmd, log_field_file,
+                    color = "blue", on_color = "on_white")
         os.system(cmd)
 
         print("\n\n")
@@ -448,7 +483,8 @@ for field in fields:
 
         script = os.path.join(pipeline_path, 'steps', 'calibration_finalzp.py')
         cmd = f'python3 {script} {field} {conf_file}'
-        ut.printlog(cmd, log_field_file)
+        ut.printlog(cmd, log_field_file,
+                    color = "blue", on_color = "on_white")
         os.system(cmd)
 
         print("\n\n")
@@ -457,20 +493,25 @@ for field in fields:
 
         script = os.path.join(pipeline_path, 'steps', 'calibration_catalog.py')
         cmd = f'python3 {script} {field} {conf_file}'
-        ut.printlog(cmd, log_field_file)
+        ut.printlog(cmd, log_field_file,
+                    color = "blue", on_color = "on_white")
         os.system(cmd)
 
         print("\n\n")
     
     if 'quality_check' in conf['run_steps']:
 
-        if conf['calibration_photometry'].lower() in ['single', 'dual']:
+        if "--dual_quality_check" in sys.argv:
             script = os.path.join(pipeline_path, 'quality_check.py')
-        elif conf['calibration_photometry'].lower() in ['psf']:
-            script = os.path.join(pipeline_path, 'quality_check_PSF.py')
+        else:
+            if conf['calibration_photometry'].lower() in ['single', 'dual']:
+                script = os.path.join(pipeline_path, 'quality_check.py')
+            elif conf['calibration_photometry'].lower() in ['psf']:
+                script = os.path.join(pipeline_path, 'quality_check_PSF.py')
 
         cmd = f'python3 {script} {field} {conf_file}'
-        ut.printlog(cmd, log_field_file)
+        ut.printlog(cmd, log_field_file,
+                    color = "blue", on_color = "on_white")
         os.system(cmd)
 
         print("\n\n")
@@ -491,10 +532,11 @@ for field in fields:
             # Only remove .fits if .fz exists:
             if os.path.exists(image_fz) and os.path.exists(image_fits):
 
-                ut.printlog(f"Removing image {image_fits}", log_field_file)
+                ut.printlog(f"Removing image {image_fits}", log_field_file,
+                             color = "red")
 
                 cmd = f"rm {image_fits}"
-                ut.printlog(cmd, log_field_file)
+                ut.printlog(cmd, log_field_file, color = "yellow")
                 os.system(cmd)
 
             if conf['use_weight']:
@@ -504,21 +546,32 @@ for field in fields:
 
                 if os.path.exists(weight_fz) and os.path.exists(weight_fits):
                     ut.printlog(f"Removing weight {weight_fits}",
-                                log_field_file)
+                                log_field_file, color = "yellow")
 
                     cmd = f"rm {weight_fits}"
-                    ut.printlog(cmd, log_field_file)
+                    ut.printlog(cmd, log_field_file, color = "red")
                     os.system(cmd)
 
+    #################################
+    # Remove all images, including fz
+
+    if os.path.exists(field_images_path) and conf["remove_images"]:
+        ut.printlog(f"Removing images, including .fz",
+                    log_field_file, color = "yellow")
+
+        cmd = f"rm -r {field_images_path}"
+        ut.printlog(cmd, log_field_file, color = "red", attrs = ["bold"])
+        os.system(cmd)
+
     #########################
     # Sync run_path and save_path field to save_path
     if conf['save_path'] != conf['run_path']:
         
         cmd = f"rsync --update -haz --progress {field_path} {conf['save_path']}"
-        ut.printlog(cmd, log_field_file)
+        ut.printlog(cmd, log_field_file, color = "blue")
         os.system(cmd)
         
         cmd = f"rm -r {field_path}"
-        ut.printlog(cmd, log_field_file)
+        ut.printlog(cmd, log_field_file, color = "red", attrs=["bold"])
         os.system(cmd)
     
