@@ -84,9 +84,8 @@ if os.path.exists(save_file):
     if quality_path:
         
         suffix = ut.calibration_suffix(conf)
-        extinction = conf['extinction_correction']
         save_file_quality_path = os.path.join(quality_path,
-                                              f'{field}_{suffix}_{extinction}.png')
+                                              f'{field}_{suffix}.png')
         
         cmd = f"cp {save_file} {save_file_quality_path}"
         os.system(cmd)
