@@ -102,10 +102,13 @@ ut.makedir(catalogs_path)
 ut.makedir(log_path)
 
 # Check for photometry folders
+has_photometry_single = "photometry_single" in conf["run_steps"]
+has_photometry_dual   = "photometry_dual" in conf["run_steps"]
+has_photometry_psf    = "photometry_psf" in conf["run_steps"]
 
-has_photometry_single = os.path.exists(single_catalog_path)
-has_photometry_dual   = os.path.exists(dual_catalog_path)
-has_photometry_psf    = os.path.exists(psf_catalog_path)
+has_photometry_single &= os.path.exists(single_catalog_path)
+has_photometry_dual   &= os.path.exists(dual_catalog_path)
+has_photometry_psf    &= os.path.exists(psf_catalog_path)
 
 if has_photometry_single:
     ut.makedir(catalogs_path_single)
@@ -247,7 +250,6 @@ def generate_detection_catalogue():
                  log_file)
     print("")
 
-
     detection_name = f'sex_{field}_detection_withIDs.fits'
     detection_file = os.path.join(dual_id_path, detection_name)
 
@@ -294,7 +296,7 @@ def generate_psf_filter_catalogues():
 
     for filt in conf['filters']:
 
-        catalog_name = f'{field}_{filt}_psf_withIDs.cat'
+        catalog_name = f'{field}_{filt}_psf_withIDs.csv'
         catalog_file = os.path.join(psf_id_path, catalog_name)
 
         zp_name = f'{field}_final.zp'
@@ -430,7 +432,7 @@ if has_photometry_dual:
 #    Extract VAC features from detection
 # ***************************************************
 
-def extract_VAC_features():
+def extract_vac_features_from_dual_mode():
 
     """
     Extracts VACs features from detection catalog
@@ -458,7 +460,10 @@ def extract_VAC_features():
             save_name = f'{field}_{filt}_dual_VAC_features.fits'
             save_file = os.path.join(catalogs_path_dual, save_name)
 
-        if not os.path.exists(save_file):
+        future_name = f'{field}_dual_VAC_features.fits'
+        future_file = os.path.join(catalogs_path_dual, future_name)
+
+        if not os.path.exists(save_file) and not os.path.exists(future_file):
             ut.extract_vac_features(catalog = catalog_file,
                                     save_file = save_file,
                                     filt = filt)
@@ -468,8 +473,9 @@ def extract_VAC_features():
         else:
             ut.printlog(f"Catalog {save_name} already exists", log_file)
 
+
 if has_photometry_dual:
-    extract_VAC_features()
+    extract_vac_features_from_dual_mode()
 
 
 # ***************************************************
@@ -496,9 +502,9 @@ def combine_vac_features():
         catalog_name = f'{field}_detection_dual_VAC_features.fits'
         catalog = os.path.join(catalogs_path_dual, catalog_name)
 
-        valuesN = f"PHOT_ID_dual"
+        valuesj = f"PHOT_ID_dual"
 
-        cmd += f"in1={catalog} ifmt1=fits values1={valuesN} "
+        cmd += f"in1={catalog} ifmt1=fits values1={valuesj} "
         cmd += f"join1=always "
 
         j = 2
@@ -506,9 +512,9 @@ def combine_vac_features():
             catalog_name = f'{field}_{filt}_dual_VAC_features.fits'
             catalog = os.path.join(catalogs_path_dual, catalog_name)
 
-            valuesN = f"PHOT_ID_dual"
+            valuesj = f"PHOT_ID_dual"
 
-            cmd += f"in{j}={catalog} ifmt{j}=fits values{j}={valuesN} "
+            cmd += f"in{j}={catalog} ifmt{j}=fits values{j}={valuesj} "
             cmd += f"join{j}=always "
             j += 1
 
@@ -523,7 +529,6 @@ def combine_vac_features():
         ut.printlog(f"Catalog {save_name} already exists", log_file)
 
 
-
 if 'photometry_dual' in conf['run_steps']:
     combine_vac_features()
 
