@@ -370,7 +370,7 @@ def get_splus_gaiascale_zero_points():
     for filt in conf['filters']:
         filters_list.append(f'SPLUS_{filt}')
 
-    save_name = f"{field}_gaiascale_splus.zp"
+    save_name = f"{field}_gaiascale_splus_tmp.zp"
     save_file = os.path.join(gaiascale_cal_path, save_name)
 
     if not os.path.exists(save_file):
@@ -387,6 +387,63 @@ def get_splus_gaiascale_zero_points():
 get_splus_gaiascale_zero_points()
 
 
+# ***************************************************
+#    Add offset to S-PLUS reference calibration
+# ***************************************************
+
+def add_offset_to_splus_reference_calibration():
+    """
+    Adds offset to S-PLUS reference calibration
+    """
+
+    if conf['offset_include_after'].lower() == "gaiascale":
+        print("")
+        ut.printlog(('********** '
+                     'Adding offset to S-PLUS reference calibration '
+                     '**********'),
+                    log_file)
+        print("")
+
+    gaiascale_zp_name = f"{field}_gaiascale_splus_tmp.zp"
+    gaiascale_zp_file = os.path.join(gaiascale_cal_path, gaiascale_zp_name)
+
+    save_name = f"{field}_gaiascale_splus.zp"
+    save_file = os.path.join(gaiascale_cal_path, save_name)
+
+    if not os.path.exists(save_file):
+
+        if conf['offset_include_after'].lower() == "gaiascale":
+            offset_zp_name = f'offset_refcalib.zp'
+            offset_zp_file = os.path.join(gaiascale_cal_path, offset_zp_name)
+
+            cmd = f"cp {conf['offset_to_splus_refcalib']} {offset_zp_file}"
+            ut.printlog(cmd, log_file)
+            os.system(cmd)
+
+            zp_file_list = [gaiascale_zp_file, offset_zp_file]
+
+            filters = []
+            for filt in conf['filters']:
+                filters.append(f"SPLUS_{filt}")
+
+            # Combine zero-points
+            ut.zp_add(zp_file_list=zp_file_list,
+                      save_file=save_file,
+                      filters=filters,
+                      inst_zp=0)
+
+        else:
+            cmd = f"cp {gaiascale_zp_file} {save_file}"
+            os.system(cmd)
+
+        ut.printlog(f"Created file {save_file}", log_file)
+
+    else:
+        ut.printlog(f"File {save_name} already exists", log_file)
+
+
+add_offset_to_splus_reference_calibration()
+
 # ***************************************************
 #    Apply Zero Points
 # ***************************************************
