@@ -139,6 +139,7 @@ for param in master_phot_params:
 #    If photometry path does not exist -> create
 # ***************************************************
 
+
 def create_id_path():
 
     print("")
@@ -192,7 +193,10 @@ def include_filter_id_in_single_mode_catalogs():
         save_name = f'sex_{field}_{filt}_single_tmp.fits'
         save_file = os.path.join(single_id_path, save_name)
 
-        if not os.path.exists(save_file):
+        future_name = f'{field}_{filt}_id+radec_single.fits'
+        future_file = os.path.join(single_id_path, future_name)
+
+        if not os.path.exists(save_file) and not os.path.exists(future_file):
             ut.assign_single_mode_filter_id(catalog   = catalog,
                                             filt      = filt,
                                             save_file = save_file,
@@ -264,7 +268,7 @@ def crossmatch_filter_id_catalogs_single():
 
     if not os.path.exists(save_file):
 
-        cmd  = f"java -jar {conf['path_to_stilts']} tmatchn "
+        cmd  = f"java -Xss4m -jar {conf['path_to_stilts']} tmatchn "
         cmd += f"nin={len(conf['filters'])} matcher=sky params=3 "
         cmd += f"multimode=group "
 
@@ -428,7 +432,7 @@ def crossmatch_filter_id_catalogs_psf():
 
     if not os.path.exists(save_file):
 
-        cmd  = f"java -jar {conf['path_to_stilts']} tmatchn "
+        cmd  = f"java -Xss8m -jar {conf['path_to_stilts']} tmatchn "
         cmd += f"nin={len(conf['filters'])} matcher=sky params=3 "
         cmd += f"multimode=group "
 
@@ -525,7 +529,7 @@ def combining_phot_ID_catalogs():
     save_file = os.path.join(photometry_path, save_name)
 
     if not os.path.exists(save_file):
-        cmd  = f"java -jar {conf['path_to_stilts']} tmatchn "
+        cmd  = f"java -Xss4m -jar {conf['path_to_stilts']} tmatchn "
         cmd += f"matcher=sky params=5 "
         cmd += f"multimode=group "
 
@@ -569,6 +573,8 @@ def combining_phot_ID_catalogs():
                 phot_id_catalog = single_file
             elif last_mode == "psf":
                 phot_id_catalog = psf_file
+            else:
+                raise ValueError(f"{last_mode} is not an acceptable value.")
 
             cmd = f"cp {phot_id_catalog} {save_file}"
             ut.printlog(cmd, log_file)
@@ -649,7 +655,7 @@ def include_field_phot_ids_in_psf_catalogs():
         id_catalog_name = f'{field}_FIELD_ID.fits'
         id_catalog = os.path.join(photometry_path, id_catalog_name)
 
-        save_name = f'{field}_{filt}_psf_withIDs.cat'
+        save_name = f'{field}_{filt}_psf_withIDs.csv'
         save_file = os.path.join(psf_id_path, save_name)
 
         filt_standard = ut.translate_filter_standard(filt)
@@ -657,13 +663,13 @@ def include_field_phot_ids_in_psf_catalogs():
 
         if not os.path.exists(save_file):
 
-            cmd = f"java -jar {conf['path_to_stilts']} tmatch2 "
+            cmd = f"java -Xss4m -jar {conf['path_to_stilts']} tmatch2 "
             cmd += f"matcher=sky params=3 join=1and2 "
             cmd += f"in1={id_catalog} ifmt1=fits "
             cmd += f"values1='PHOT_ID_RA_psf PHOT_ID_DEC_psf' "
             cmd += f"in2={catalog_file} ifmt2=ascii "
             cmd += f"values2={values2} "
-            cmd += f"out={save_file} ofmt=ascii"
+            cmd += f"out={save_file} ofmt=csv"
 
             print(cmd)
             os.system(cmd)
@@ -712,7 +718,7 @@ def include_field_phot_ids_in_dual_catalogs():
         save_file = os.path.join(dual_id_path, save_name)
 
         if not os.path.exists(save_file):
-            cmd  = f"java -jar {conf['path_to_stilts']} tmatch2 "
+            cmd  = f"java -Xss4m -jar {conf['path_to_stilts']} tmatch2 "
             cmd += f"matcher=sky params=3 join=1and2 "
             cmd += f"in1={id_catalog} ifmt1=fits "
             cmd += f"values1='PHOT_ID_RA_dual PHOT_ID_DEC_dual' "
@@ -757,7 +763,7 @@ def include_field_phot_ids_in_detection_catalog():
     save_file = os.path.join(dual_id_path, save_name)
 
     if not os.path.exists(save_file):
-        cmd = f"java -jar {conf['path_to_stilts']} tmatch2 "
+        cmd = f"java -Xss4m -jar {conf['path_to_stilts']} tmatch2 "
         cmd += f"matcher=sky params=3 join=1and2 "
         cmd += f"in1={id_catalog} ifmt1=fits "
         cmd += f"values1='PHOT_ID_RA_dual PHOT_ID_DEC_dual' "
@@ -802,7 +808,7 @@ def include_field_phot_ids_in_single_catalogs():
         save_file = os.path.join(single_id_path, save_name)
 
         if not os.path.exists(save_file):
-            cmd  = f"java -jar {conf['path_to_stilts']} tmatch2 "
+            cmd  = f"java -Xss4m -jar {conf['path_to_stilts']} tmatch2 "
             cmd += f"matcher=sky params=3 join=1and2 "
             cmd += f"in1={id_catalog} ifmt1=fits "
             cmd += f"values1='PHOT_ID_RA_single PHOT_ID_DEC_single' "
