@@ -104,7 +104,8 @@ with open(log_file, "w") as log:
 ################################################################################
 # Log configuration
 
-ut.printlog("Dual mode photometry parameters:", log_file)
+ut.printlog("Dual mode photometry parameters:", log_file,
+            color = "blue", attrs=["bold"])
 
 dual_mode_params = ['run_path', 'filters', 'path_to_images', 'inst_zp',
                     'use_weight', 'path_to_sex', 'sex_config', 'sex_param',
@@ -112,9 +113,11 @@ dual_mode_params = ['run_path', 'filters', 'path_to_images', 'inst_zp',
 
 for param in dual_mode_params:
     try:
-        ut.printlog(f"{param}: {conf[param]}", log_file)
+        ut.printlog(f"{param}: {conf[param]}", log_file,
+                    color = "blue")
     except KeyError:
-        ut.printlog(f"{param}: NONE", log_file)
+        ut.printlog(f"{param}: NONE", log_file,
+                     color = "red")
 
 ################################################################################
 # Begin script
@@ -130,7 +133,7 @@ def create_photometry_path():
     ut.printlog(('********** '
                  'Generating Dual Photometry paths '
                  '**********'),
-                 log_file)
+                 log_file, color = "yellow")
     print("")
 
     # Create dual mode photometry path
@@ -161,7 +164,7 @@ def generate_swarp_config():
     print("")
     ut.printlog(('********** '
                  'Generating swarp configuration '
-                 '**********'), log_file)
+                 '**********'), log_file, color = "yellow")
     print("")
 
     save_file = os.path.join(detection_path, f'{field}_config.swarp')
@@ -200,10 +203,12 @@ def generate_swarp_config():
                             weight_type          = weight_type,
                             ref_image            = image_file)
 
-        ut.printlog(f"Created file {save_file}", log_file)
+        ut.printlog(f"Created file {save_file}", log_file,
+                    color = "green")
 
     else:
-        ut.printlog(f"File {save_file} already created.", log_file)
+        ut.printlog(f"File {save_file} already created.", log_file,
+                    color = "white", attrs=["dark"])
 
 
 generate_swarp_config()
@@ -222,7 +227,7 @@ def generate_combine_images_list():
     print("")
     ut.printlog(('********** '
                  'Generating list of images to combine '
-                 '**********'), log_file)
+                 '**********'), log_file, color = "yellow")
     print("")
 
     save_file = os.path.join(detection_path, f'combine_images.txt')
@@ -238,10 +243,12 @@ def generate_combine_images_list():
                 imlist.write(image_file)
                 imlist.write("\n")
 
-        ut.printlog(f"Created file combine_images.txt", log_file)
+        ut.printlog(f"Created file combine_images.txt", log_file,
+                    color = "green")
 
     else:
-        ut.printlog(f"{save_file} already created.", log_file)
+        ut.printlog(f"{save_file} already created.", log_file,
+                    color = "white", attrs = ["dark"])
 
 
 generate_combine_images_list()
@@ -260,7 +267,7 @@ def generate_detection_image():
     print("")
     ut.printlog(('********** '
                  'Generating Detection Image '
-                 '**********'), log_file)
+                 '**********'), log_file, color = "yellow")
     print("")
 
     det_image_name = f"{field}_detection.fits"
@@ -279,15 +286,17 @@ def generate_detection_image():
             # Prepare swarp cmd
             cmd = f"{conf['path_to_swarp']} @{image_list} -c {swarp_conf}"
 
-            ut.printlog("$ "+cmd, log_file)
+            ut.printlog("$ "+cmd, log_file, color = "cyan")
 
             # Run swarp
             os.system(cmd)
 
         else:
-            ut.printlog(f"File {det_image_file} already exists.", log_file)
+            ut.printlog(f"File {det_image_file} already exists.", log_file,
+                        color = white, attrs=["dark"])
     else:
-        ut.printlog(f"File {det_image_fz} already exists.", log_file)
+        ut.printlog(f"File {det_image_fz} already exists.", log_file,
+                    color = "white", attrs=["dark"])
 
 
 generate_detection_image()
@@ -307,7 +316,7 @@ def update_detection_header():
     ut.printlog(('********** '
                  'Updating detection image header '
                  '**********'),
-                log_file)
+                log_file, color = "yellow")
     print("")
 
     # Get detection image file
@@ -331,7 +340,8 @@ def update_detection_header():
             f.write("Detection header was updated.")
 
     else:
-        ut.printlog("Detection header already updated.", log_file)
+        ut.printlog("Detection header already updated.", log_file,
+                    color = "white", attrs=["dark"])
 
 
 update_detection_header()
@@ -351,7 +361,7 @@ def generate_detection_sexconfig_file():
     ut.printlog(('********** '
                  'Generating detection image photometry config files '
                  '**********'),
-                log_file)
+                log_file, color = "yellow")
     print("")
 
     # Default SExconfig and SExparam files
@@ -387,11 +397,11 @@ def generate_detection_sexconfig_file():
                           check_aperima=aper_image)
 
         ut.printlog(f"Generated detection image sexconfig for field {field}",
-                    log_file)
+                    log_file, color = "green")
 
     else:
         ut.printlog(("Detection image sexconfig already obtained for field "
-                     f"{field}"), log_file)
+                     f"{field}"), log_file, color = "white", attrs=["dark"])
 
 
 generate_detection_sexconfig_file()
@@ -411,7 +421,7 @@ def generate_dual_sexconfig_files():
     ut.printlog(('********** '
                  'Generating Dual Photometry config files '
                  '**********'),
-                 log_file)
+                 log_file, color = "yellow")
     print("")
 
     # Default SExconfig and SExparam files
@@ -451,15 +461,17 @@ def generate_dual_sexconfig_files():
                               detection_file    = detection_file)
 
             ut.printlog(("Generated dual mode sexconfig for field "
-                         f"{field}, filter {filt}"), log_file)
+                         f"{field}, filter {filt}"), log_file,
+                         color = "green")
 
         else:
             ut.printlog(("Dual mode sexconfig already obtained for field "
-                         f"{field}, filter {filt}"), log_file)
+                         f"{field}, filter {filt}"), log_file,
+                         color = "white", attrs=["dark"])
 
     # Copy sexparam file to field config directory (for proper documentation)
     cmd = f'cp {default_sexparam} {sexconf_path}'
-    ut.printlog("$ "+cmd, log_file)
+    ut.printlog("$ "+cmd, log_file, color = "green")
     os.system(cmd)
 
 
@@ -480,7 +492,7 @@ def run_sex_detection():
     ut.printlog(('********** '
                  'Running SeX on detection image '
                  '**********'),
-                 log_file)
+                 log_file, color = "yellow")
     print("")
 
     # Generate location of output catalog file
@@ -502,12 +514,12 @@ def run_sex_detection():
 
         cmd = f"{sex_location} {image_file} -c {sexconf_file}"
         cmd += " -PHOT_APERTURES '5.45455, 36.363636'"
-        ut.printlog("$ "+cmd, log_file)
+        ut.printlog("$ "+cmd, log_file, color = "cyan")
         os.system(cmd)
 
     else:
         ut.printlog(("Detection image photometry already obtained for field "
-                     f"{field}"), log_file)
+                     f"{field}"), log_file, color = "white", attrs = ["dark"])
 
 
 run_sex_detection()
@@ -527,7 +539,7 @@ def run_sex_dual():
     ut.printlog(('********** '
                  'Running SeX in dual mode '
                  '**********'),
-                 log_file)
+                 log_file, color = "yellow")
     print("")
 
     for filt in conf['filters']:
@@ -556,12 +568,13 @@ def run_sex_dual():
             cmd = (f"{sex_location} {detection_file}, {image_file} "
                    f"-c {sexconf_file}")
 
-            ut.printlog("$ "+cmd, log_file)
+            ut.printlog("$ "+cmd, log_file, color = "cyan")
             os.system(cmd)
 
         else:
             ut.printlog(("Dual mode photometry already obtained for field "
-                         f"{field}, filter {filt}"), log_file)
+                         f"{field}, filter {filt}"), log_file,
+                         color = "white", attrs = ["dark"])
 
 
 run_sex_dual()
@@ -584,7 +597,7 @@ def convert_detection_fits_to_fz():
     ut.printlog(('********** '
                  'Converting detection .fits to .fz '
                  '**********'),
-                 log_file)
+                 log_file, color = "yellow")
     print("")
 
     det_image_name = f"{field}_detection.fits"
@@ -603,20 +616,22 @@ def convert_detection_fits_to_fz():
 
             # Compress fits
             cmd = f"fpack {image}"
-            ut.printlog("$ " + cmd, log_file)
+            ut.printlog("$ " + cmd, log_file, color = "cyan")
             os.system(cmd)
 
         else:
-            ut.printlog(f"{name} image already compressed.", log_file)
+            ut.printlog(f"{name} image already compressed.", log_file,
+                        color = "white", attrs = ["dark"])
 
         if os.path.exists(image + '.fz'):
             # Remove fits
             cmd = f"rm {image}"
-            ut.printlog("$ " + cmd, log_file)
+            ut.printlog("$ " + cmd, log_file, color = "red")
             os.system(cmd)
 
         else:
-            ut.printlog(f"{name} fits image already deleted.", log_file)
+            ut.printlog(f"{name} fits image already deleted.", log_file,
+                        color = "white", attrs = ["dark"])
 
 
 convert_detection_fits_to_fz()
@@ -635,7 +650,7 @@ def dual_diagnostic_plots():
     ut.printlog(('********** '
                  'Making diagnostic plots for dual mode photometry'
                  '**********'),
-                log_file)
+                log_file, color = "yellow")
     print("")
 
     for filt in conf['filters']:
@@ -659,14 +674,17 @@ def dual_diagnostic_plots():
                                    sexconf   = sexconf_file,
                                    filt      = filt)
 
-            ut.printlog(f"Created file {save_file}", log_file)
+            ut.printlog(f"Created file {save_file}", log_file,
+                        color = "green")
 
         else:
             ut.printlog(("Diagnostic plots already made for field "
-                         f"{field}, filter {filt}"), log_file)
+                         f"{field}, filter {filt}"), log_file,
+                         color = "white", attrs = ["dark"])
 
 
 dual_diagnostic_plots()
 
 
-ut.printlog("COMPLETED DUAL MODE PHOTOMETRY", log_file)
\ No newline at end of file
+ut.printlog("COMPLETED DUAL MODE PHOTOMETRY", log_file, 
+        color = "yellow", attrs=["bold", "reverse"])
